@@ -9,7 +9,7 @@ use App::Netdisco::Util::Permission qw/acl_matches acl_matches_only/;
 use App::Netdisco::Util::FastResolver 'hostnames_resolve_async';
 use App::Netdisco::Util::Device 'get_device';
 use App::Netdisco::Util::DNS 'hostname_from_ip';
-use App::Netdisco::Util::SNMP 'snmp_comm_reindex';
+use App::Netdisco::Util::SNMP qw/snmp_comm_reindex get_mibdirs_shortnames/;
 use App::Netdisco::Util::Web 'sort_port';
 use App::Netdisco::DB::ExplicitLocking ':modes';
 
@@ -106,7 +106,9 @@ register_worker({ phase => 'early', driver => 'snmp',
   }
 
   # fix up model using products OID cache
-  if ($try_vendor) {
+  if ((not $device->model or $device->model eq 'unknown'
+        or $device->model =~ m/(?:product|enterprise|1\.3\.6\.1)/i) and $try_vendor) {
+
       my $oid = '.1.3.6.1.4.1' . $try_vendor;
       debug sprintf ' searching for Product ID "%s"', ('enterprises' . $try_vendor);
       my $object = schema('netdisco')->resultset('Product')->find($oid);
@@ -117,6 +119,21 @@ register_worker({ phase => 'early', driver => 'snmp',
       }
   }
 
+  # remove superfluous vendor names from model names
+  if ($device->model) {
+      my @extravendors = qw/jnxProduct jnxProductName/;
+      my @vendors = sort {length($b) <=> length($a)} (@extravendors, @{ get_mibdirs_shortnames() });
+      my $vend_pat = '^(?:' . join('|', @vendors) . ')';
+      my $vend_re = qr/$vend_pat/;
+
+      (my $model = $device->model) =~ s/$vend_re//i;
+      if ($model and $model ne $device->model) {
+          debug sprintf ' fixing Product Name to be "%s" (was "%s")',
+            $model, $device->model;
+          $device->set_column( model => $model );
+      }
+  }
+
   # protection for failed SNMP gather
   if (setting('enable_field_protection') and not $device->is_pseudo) {
       my $category = ($device->in_storage ? 'device' : 'new_device');
